CredentialSubject class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CredentialSubject({required String passportNumber, required DateTime dateOfBirth, required String address})
-
CredentialSubject.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → String
-
final
- dateOfBirth → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passportNumber → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited