Wallet class

Constructors

Wallet({required String id, required String name, required DateTime createdOn, required DateTime addedOn, required String permission})
Wallet.fromJson(Map<String, dynamic> json)
factory
Wallet.initial()
factory

Properties

addedOn DateTime
final
createdOn DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
permission String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited