WalletService class

Constructors

WalletService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completePresentCredential(String cookie, String isAccepted, String url) Future<void>
formatCamelCaseString(String input) String
getDids(String cookie, String walletId) Future<List<DidType>>
getWallet(String cookie) Future<List<Wallet>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
presentCredential(String url, List<Wallet> wallets, String cookie) Future<List<VaultCredential>>
resolveCredential(String url, String walletId, String cookie) Future<List<String>>
toString() String
A string representation of this object.
inherited
updateTransaction(String cookie, String userInput, String openIdOffer, String walletId, dynamic callback) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited