VaultTheme class

Constructors

VaultTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

baseHeight double
no setter
baseWidth double
no setter
hrem double
no setter
rem double
no setter
screenHeight double
no setter
screenWidth double
no setter

Static Methods

setTheme(BuildContext context) → dynamic