ParsedDocument class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ParsedDocument({required List<
String> context, required List<String> type, required String id, required Issuer issuer, required DateTime issuanceDate, DateTime? validFrom, DateTime? expirationDate, required CredentialSubject credentialSubject, List<Evidence> ? evidence, CredentialStatus? credentialStatus, CredentialSchema? credentialSchema}) -
ParsedDocument.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
context
→ List<
String> -
final
- credentialSchema → CredentialSchema?
-
final
- credentialStatus → CredentialStatus?
-
final
- credentialSubject → CredentialSubject
-
final
-
evidence
→ List<
Evidence> ? -
final
- expirationDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- issuanceDate → DateTime
-
final
- issuer → Issuer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ List<
String> -
final
- validFrom → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited