VaultCredential class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
VaultCredential({required String wallet, required String id, required String document, required String format, required String disclosures, required DateTime addedOn, DateTime? deletedOn, required bool pending, required Map<
String, dynamic> parsedDocument}) -
VaultCredential.fromJson(Map<
String, dynamic> json) -
factory
- VaultCredential.initial()
-
factory
Properties
- addedOn → DateTime
-
final
- deletedOn → DateTime?
-
final
- disclosures → String
-
final
- document → String
-
final
- format → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
parsedDocument
→ Map<
String, dynamic> -
final
- pending → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wallet → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited